==> medlogics-common-classes-1.1-20251109.055933-451.jar: com/floreantpos/report/DeletedItem.java <==
package com.floreantpos.report;

import java.util.Date;

import com.floreantpos.model.User;

public class DeletedItem {

	private String id;
	private Date voidDate;
	private String ticketId;
	private String name;
	private double quantity;
	private double total;
	private String voidReason;
	private Boolean itemWasted;
	private User owner;
	private User voidUser;
	private String voidUserName;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public Date getVoidDate() {
		return voidDate;
	}

	public void setVoidDate(Date date) {
		this.voidDate = date;
	}

	public String getTicketId() {
		return ticketId;
	}

	public void setTicketId(String ticketId) {
		this.ticketId = ticketId;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public double getQuantity() {
		return quantity;
	}

	public void setQuantity(double quantity) {
		this.quantity = quantity;
	}

	public double getTotal() {
		return total;
	}

	public void setTotal(double total) {
		this.total = total;
	}

	public String getVoidReason() {
		return voidReason;
	}

	public void setVoidReason(String voidReason) {
		this.voidReason = voidReason;
	}

	public User getOwner() {
		return owner;
	}

	public void setOwner(User owner) {
		this.owner = owner;
	}

	public User getVoidUser() {
		return voidUser;
	}

	public void setVoidUser(User voidUser) {
		this.voidUser = voidUser;
	}

	public Boolean getItemWasted() {
		return itemWasted;
	}

	public void setItemWasted(Boolean itemWasted) {
		this.itemWasted = itemWasted;
	}

	public String getVoidUserName() {
		return voidUserName;
	}

	public void setVoidUserName(String voidUserName) {
		this.voidUserName = voidUserName;
	}
}

==> medlogics-common-classes-1.1-20251204.094222-505.jar: com/floreantpos/report/DeletedItem.java <==
package com.floreantpos.report;

import java.util.Date;

import com.floreantpos.model.User;

public class DeletedItem {

	private String id;
	private Date voidDate;
	private String ticketId;
	private String name;
	private double quantity;
	private double total;
	private double tax;
	private String voidReason;
	private Boolean itemWasted;
	private User owner;
	private User voidUser;
	private String voidUserName;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public Date getVoidDate() {
		return voidDate;
	}

	public void setVoidDate(Date date) {
		this.voidDate = date;
	}

	public String getTicketId() {
		return ticketId;
	}

	public void setTicketId(String ticketId) {
		this.ticketId = ticketId;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public double getQuantity() {
		return quantity;
	}

	public void setQuantity(double quantity) {
		this.quantity = quantity;
	}

	public double getTotal() {
		return total;
	}

	public void setTotal(double total) {
		this.total = total;
	}

	public String getVoidReason() {
		return voidReason;
	}

	public void setVoidReason(String voidReason) {
		this.voidReason = voidReason;
	}

	public User getOwner() {
		return owner;
	}

	public void setOwner(User owner) {
		this.owner = owner;
	}

	public User getVoidUser() {
		return voidUser;
	}

	public void setVoidUser(User voidUser) {
		this.voidUser = voidUser;
	}

	public Boolean getItemWasted() {
		return itemWasted;
	}

	public void setItemWasted(Boolean itemWasted) {
		this.itemWasted = itemWasted;
	}

	public String getVoidUserName() {
		return voidUserName;
	}

	public void setVoidUserName(String voidUserName) {
		this.voidUserName = voidUserName;
	}

	public double getTax() {
		return tax;
	}

	public void setTax(double tax) {
		this.tax = tax;
	}
}
